==> nomadic_2025_01_17.zip: nomadic/storage/framework/views/8bf8750432394ca06b32390e531cdfc192ff3c13.php <==
<?php if(session()->has('notifications') && count(session()->get('notifications')) > 0): ?>
  <?php $__currentLoopData = session()->get('notifications'); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $notifi): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    <?php if($notifi->type=='booking' && $notifi->action=='cancelled'): ?>
    <li class="notification-item w310">
      <i class="bi bi-x-circle text-danger"></i>
      <div>
        <h4>Booking Cancelled</h4>
        <p><?php echo $notifi->content; ?></p>
        <p><a href="<?php echo e(url('booking-confirmed/'.$notifi->reference_id)); ?>"><span class="badge rounded-pill bg-primary p-2 ms-2">View Booking</span></a></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='booking' && $notifi->action=='confirmed'): ?>
    <li class="notification-item w310">
      <i class="bi bi-check-circle text-success"></i>
      <div>
        <h4>Booking Confirmed</h4>
        <p><?php echo $notifi->content; ?></p>
        <p><a href="<?php echo e(url('booking-confirmed/'.$notifi->reference_id)); ?>"><span class="badge rounded-pill bg-primary p-2 ms-2">View Booking</span></a></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_PURCHASED'): ?>
    <li class="notification-item w310">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Purchased Points</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_RECEIVED'): ?>
    <li class="notification-item w310">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Points Received</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_SENT'): ?>
    <li class="notification-item w310">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Points Sent</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='MEMBERSHIP_CREDIT'): ?>
    <li class="notification-item w310">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Membership Credit</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='subscription' && $notifi->action=='cancelled'): ?>
    <li class="notification-item w310">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Subscription Cancelled</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php endif; ?>
  <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
<?php else: ?>
<li class="notification-item w310">
  <div class="ms-3">Notifications not available.</div>
</li>
<?php endif; ?><?php /**PATH /var/www/html/nomadic/resources/views/notification.blade.php ENDPATH**/ ?>

==> nomadic_2025_07_19.zip: nomadic/storage/framework/views/8bf8750432394ca06b32390e531cdfc192ff3c13.php <==
<?php if(session()->has('notifications') && count(session()->get('notifications')) > 0): ?>
  <?php $__currentLoopData = session()->get('notifications'); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $notifi): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    <?php if($notifi->type=='booking' && $notifi->action=='cancelled'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-x-circle text-danger"></i>
      <div>
        <h4>Booking Cancelled</h4>
        <p><?php echo $notifi->content; ?></p>
        <p><a href="<?php echo e(url('booking-confirmed/'.$notifi->reference_id)); ?>"><span class="badge rounded-pill bg-primary p-2 ms-2">View Booking</span></a></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='booking' && $notifi->action=='confirmed'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-check-circle text-success"></i>
      <div>
        <h4>Booking Confirmed</h4>
        <p><?php echo $notifi->content; ?></p>
        <p><a href="<?php echo e(url('booking-confirmed/'.$notifi->reference_id)); ?>"><span class="badge rounded-pill bg-primary p-2 ms-2">View Booking</span></a></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_PURCHASED'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Purchased Points</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_RECEIVED'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Points Received</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_EXPIRED'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Points Expired</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_SENT'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Points Sent</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_SENT_EVENT'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Points Sent For EVENT</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='POINTS_RECEIVED_EVENT'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Points Received For Event</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='point' && $notifi->action=='MEMBERSHIP_CREDIT'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Membership Credit</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php elseif($notifi->type=='subscription' && $notifi->action=='cancelled'): ?>
    <li class="notification-item p-3">
      <i class="bi bi-info-circle text-primary"></i>
      <div>
        <h4>Subscription Cancelled</h4>
        <p><?php echo $notifi->content; ?></p>
      </div>
    </li>
    <li>
      <hr class="dropdown-divider">
    </li>
    <?php endif; ?>
  <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
<?php else: ?>
<li class="notification-item p-3">
  <div class="ms-3">Notifications not available.</div>
</li>
<?php endif; ?><?php /**PATH /var/www/html/nomadic/resources/views/notification.blade.php ENDPATH**/ ?>
